@@ -1,10 +1,6 @@
-#!/usr/bin/env python
+# -*- coding: utf-8 -*-
 #
-# $Revision: 1.34 $
-# $Date: 2005/09/14 22:49:39 $
-# $Author: dwelch $
-#
-# (c) Copyright 2003-2004 Hewlett-Packard Development Company, L.P.
+# (c) Copyright 2003-2006 Hewlett-Packard Development Company, L.P.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -67,17 +63,21 @@ ERROR_INTERFACE_BUSY = 36
 ERROR_DEVICEOPEN_FAILED_ONE_DEVICE_ONLY = 37
 ERROR_DEVICEOPEN_FAILED_DEV_NODE_MOVED = 38
 ERROR_TEST_EMAIL_FAILED = 39
-ERROR_SMTP_CONNECT_ERROR = 40
-ERROR_SMTP_RECIPIENTS_REFUSED = 41
-ERROR_SMTP_HELO_ERROR = 42
-ERROR_SMTP_SENDER_REFUSED = 43
-ERROR_SMTP_DATA_ERROR = 44
+#ERROR_SMTP_CONNECT_ERROR = 40
+#ERROR_SMTP_RECIPIENTS_REFUSED = 41
+#ERROR_SMTP_HELO_ERROR = 42
+#ERROR_SMTP_SENDER_REFUSED = 43
+#ERROR_SMTP_DATA_ERROR = 44
 ERROR_INVALID_HOSTNAME = 45
 ERROR_INVALID_PORT_NUMBER = 46
 ERROR_NO_CUPS_QUEUE_FOUND_FOR_DEVICE = 47
 ERROR_UNSUPPORTED_MODEL = 48
-ERROR_UNABLE_TO_BIND_SOCKET = 95
+ERROR_FAX_FILE_NOT_FOUND = 49
+ERROR_FAX_INCOMPATIBLE_OPTIONS = 50
+ERROR_FAX_INVALID_FAX_FILE = 51
+ERROR_FAX_MUST_RUN_SENDFAX_FIRST = 52
 # --> add new codes here <--
+ERROR_UNABLE_TO_BIND_SOCKET = 95
 ERROR_UNABLE_TO_CONTACT_SERVICE = 96
 ERROR_DEVICE_NOT_OPEN = 98
 ERROR_INTERNAL = 99
@@ -101,6 +101,8 @@ STATUS_UNKNOWN = 0
 
 EVENT_START_PRINT_JOB = 500 # sent by hp: backend
 EVENT_END_PRINT_JOB = 501 # sent by hp: backend
+EVENT_START_FAX_PRINT_JOB = 600 # sent by hpfax: backend
+EVENT_END_FAX_PRINT_JOB = 601 # sent by hpfax: backend
 
 STATUS_PRINTER_BASE = 1000
 STATUS_PRINTER_IDLE = 1000
@@ -180,6 +182,7 @@ STATUS_PRINTER_OFFLINE = 1803
 STATUS_PRINTER_LOW_TONER = 1804
 STATUS_PRINTER_NO_TONER = 1805
 STATUS_PRINTER_SERVICE_REQUEST = 1806
+STATUS_PRINTER_FUSER_ERROR = 1807
 #end
 
 # other "synthetic" codes
@@ -196,12 +199,16 @@ EVENT_SCANNER_FAIL = 2002
 EVENT_START_FAX_JOB = 3000
 EVENT_END_FAX_JOB = 3001
 EVENT_FAX_JOB_FAIL = 3002
+EVENT_FAX_JOB_CANCELED = 3003
+STATUS_FAX_TX_ACTIVE = 3004
+STATUS_FAX_RX_ACTIVE = 3005
 #end
 
 # copy
 EVENT_START_COPY_JOB = 4000
 EVENT_END_COPY_JOB = 4001
 EVENT_COPY_JOB_FAIL = 4002
+EVENT_COPY_JOB_CANCELED = 4003
 #end
 
 # Adding the ERROR_CODE_BASE to the above
@@ -246,6 +253,7 @@ EVENT_ERROR_INVALID_GUI_NAME = 5035
 EVENT_ERROR_INTERFACE_BUSY = 5036
 EVENT_ERROR_DEVICEOPEN_FAILED_ONE_DEVICE_ONLY = 5037
 EVENT_ERROR_DEVICEOPEN_FAILED_DEV_NODE_MOVED = 5038
+EVENT_ERROR_FAX_MUST_RUN_SENDFAX_FIRST = 5052
 # end
 
 # pcard
@@ -256,18 +264,23 @@ EVENT_PCARD_UNABLE_TO_MOUNT = 6003
 EVENT_PCARD_FILES_TRANSFERED = 6004
 # end
 
-# toolbox
-EVENT_UI_SHOW_TOOLBOX = 7000
-EVENT_UI_HIDE_TOOLBOX = 7001
-# end
+EVENT_MAX_USER_EVENT = 7999
+# end of user events
+# start of internal events
 
-# fax
+# fax (internal events)
 EVENT_FAX_MIN = 8000
-EVENT_FAX_RENDERED = 8000 # sent by hpfax: after job rendered and spooled
-EVENT_FAX_RECEIPTS_SET = 8001 # sent by sendfax after receips and options gathered
+EVENT_FAX_RENDER_COMPLETE = 8000 # sent by hpssd to hp-sendfax after job rendered
+EVENT_FAX_ADDRESS_BOOK_UPDATED = 8002 # Sent by FAB to indicate that the dB has changed
+EVENT_FAX_RENDER_DISTANT_EARLY_WARNING = 8003
 EVENT_FAX_MAX = 8999
 # end
 
+EVENT_CUPS_QUEUES_CHANGED = 9000 # sent by hp-setup if queues added (or removed)
+
+# end of events
+
+
 # Error states
 ERROR_STATE_CLEAR = 0        # Show icon w/o overlay
 ERROR_STATE_OK = 1           # Icon w/ "OK" overlay
@@ -275,6 +288,7 @@ ERROR_STATE_WARNING = 2      # Icon w/ triangle "!" overlay
 ERROR_STATE_ERROR = 3        # Icon w/ circle "X" overlay
 ERROR_STATE_LOW_SUPPLIES = 4 # Icon w/ supplies overlay
 ERROR_STATE_BUSY = 5         # Icon with busy overlay
+ERROR_STATE_LOW_PAPER = 6    # Icon w/ paper low overlay
 #end
 
 
@@ -283,6 +297,8 @@ STATUS_TO_ERROR_STATE_MAP = {
     STATUS_UNKNOWN : ERROR_STATE_CLEAR,
     EVENT_START_PRINT_JOB : ERROR_STATE_BUSY,
     EVENT_END_PRINT_JOB   : ERROR_STATE_OK,
+    EVENT_START_FAX_PRINT_JOB : ERROR_STATE_CLEAR,
+    EVENT_END_FAX_PRINT_JOB : ERROR_STATE_OK,
     STATUS_PRINTER_IDLE : ERROR_STATE_CLEAR,
     STATUS_PRINTER_BUSY : ERROR_STATE_BUSY,
     STATUS_PRINTER_PRINTING : ERROR_STATE_BUSY,
@@ -321,7 +337,7 @@ STATUS_TO_ERROR_STATE_MAP = {
     STATUS_PRINTER_OUTPUT_TRAY_CLOSED : ERROR_STATE_ERROR,
     STATUS_PRINTER_MANUAL_FEED_BLOCKED : ERROR_STATE_ERROR,
     STATUS_PRINTER_REAR_FEED_BLOCKED : ERROR_STATE_ERROR,
-    STATUS_PRINTER_TRAY_2_OUT_OF_PAPER : ERROR_STATE_ERROR,
+    STATUS_PRINTER_TRAY_2_OUT_OF_PAPER : ERROR_STATE_LOW_PAPER,
     STATUS_PRINTER_UNABLE_TO_LOAD_FROM_LOCKED_TRAY : ERROR_STATE_ERROR,
     STATUS_PRINTER_NON_HP_INK : ERROR_STATE_WARNING,
     STATUS_PRINTER_PEN_CALIBRATION_RESUME : ERROR_STATE_WARNING,
@@ -330,12 +346,13 @@ STATUS_TO_ERROR_STATE_MAP = {
     STATUS_PRINTER_PEN_CLEANING : ERROR_STATE_WARNING,
     STATUS_PRINTER_PEN_CLEANING : ERROR_STATE_WARNING,
     STATUS_PRINTER_WARMING_UP : ERROR_STATE_BUSY,
-    STATUS_PRINTER_LOW_PAPER : ERROR_STATE_LOW_SUPPLIES,
+    STATUS_PRINTER_LOW_PAPER : ERROR_STATE_LOW_PAPER,
     STATUS_PRINTER_DOOR_OPEN : ERROR_STATE_ERROR,
     STATUS_PRINTER_OFFLINE : ERROR_STATE_ERROR,
     STATUS_PRINTER_LOW_TONER : ERROR_STATE_LOW_SUPPLIES,
     STATUS_PRINTER_NO_TONER : ERROR_STATE_LOW_SUPPLIES,
     STATUS_PRINTER_SERVICE_REQUEST : ERROR_STATE_ERROR,
+    STATUS_PRINTER_FUSER_ERROR : ERROR_STATE_ERROR,
     STATUS_DEVICE_UNSUPPORTED : ERROR_STATE_ERROR,
     # The following block are EVENTs because they are only
     # recieved as events from hpiod, hp backend, etc.
@@ -370,7 +387,7 @@ STATUS_TO_ERROR_STATE_MAP = {
     EVENT_ERROR_INVALID_SERVICE_NAME : ERROR_STATE_ERROR,
     EVENT_ERROR_INVALID_USER_ERROR_CODE : ERROR_STATE_ERROR,
     EVENT_ERROR_ERROR_INVALID_CHANNEL_ID : ERROR_STATE_ERROR,
-    EVENT_ERROR_CHANNEL_BUSY : ERROR_STATE_ERROR,
+    EVENT_ERROR_CHANNEL_BUSY : ERROR_STATE_BUSY,
     EVENT_ERROR_CHANNEL_CLOSE_FAILED : ERROR_STATE_ERROR,
     EVENT_ERROR_UNSUPPORTED_BUS_TYPE : ERROR_STATE_ERROR,
     EVENT_ERROR_DEVICE_DOES_NOT_SUPPORT_OPERATION : ERROR_STATE_ERROR,
@@ -378,15 +395,23 @@ STATUS_TO_ERROR_STATE_MAP = {
     EVENT_ERROR_INTERFACE_BUSY : ERROR_STATE_BUSY,
     EVENT_ERROR_DEVICEOPEN_FAILED_ONE_DEVICE_ONLY : ERROR_STATE_ERROR,
     EVENT_ERROR_DEVICEOPEN_FAILED_DEV_NODE_MOVED : ERROR_STATE_ERROR,
+    
     EVENT_START_SCAN_JOB : ERROR_STATE_BUSY,
     EVENT_END_SCAN_JOB : ERROR_STATE_OK,
     EVENT_SCANNER_FAIL : ERROR_STATE_ERROR,
+    
     EVENT_START_FAX_JOB : ERROR_STATE_BUSY,
     EVENT_END_FAX_JOB : ERROR_STATE_OK,
     EVENT_FAX_JOB_FAIL : ERROR_STATE_ERROR,
+    EVENT_FAX_JOB_CANCELED : ERROR_STATE_ERROR,
+    STATUS_FAX_TX_ACTIVE : ERROR_STATE_BUSY,
+    STATUS_FAX_RX_ACTIVE : ERROR_STATE_BUSY,
+    
     EVENT_START_COPY_JOB : ERROR_STATE_BUSY,
     EVENT_END_COPY_JOB : ERROR_STATE_OK,
-    EVENT_FAX_JOB_FAIL : ERROR_STATE_ERROR,
+    EVENT_COPY_JOB_FAIL : ERROR_STATE_ERROR,
+    EVENT_COPY_JOB_CANCELED : ERROR_STATE_ERROR,
+    
     EVENT_START_PCARD_JOB : ERROR_STATE_BUSY,
     EVENT_END_PCARD_JOB : ERROR_STATE_CLEAR,
     EVENT_PCARD_JOB_FAIL : ERROR_STATE_ERROR,
@@ -415,9 +440,9 @@ IO_STATE_NON_HP = 3
 
 # 'kind'
 AGENT_KIND_NONE = 0
-AGENT_KIND_HEAD = 1 # InkJet
-AGENT_KIND_SUPPLY = 2 # InkJet
-AGENT_KIND_HEAD_AND_SUPPLY = 3 # InkJet
+AGENT_KIND_HEAD = 1 # InkJet head (no ink)
+AGENT_KIND_SUPPLY = 2 # InkJet supply (ink tank)
+AGENT_KIND_HEAD_AND_SUPPLY = 3 # InkJet (cartridge)
 AGENT_KIND_TONER_CARTRIDGE = 4 # LaserJet
 AGENT_KIND_MAINT_KIT = 5 # LaserJet "Maintenance kit (fuser)"
 AGENT_KIND_ADF_KIT = 6 # LaserJet "Document feeder kit"
@@ -437,8 +462,16 @@ AGENT_TYPE_YELLOW = 6
 AGENT_TYPE_CYAN_LOW = 7
 AGENT_TYPE_MAGENTA_LOW = 8
 AGENT_TYPE_YELLOW_LOW = 9
-AGENT_TYPE_GGK = 10
+AGENT_TYPE_GGK = 10 # 2 shades of grey and black
 AGENT_TYPE_BLUE = 11
+AGENT_TYPE_KCMY_CM = 12 
+AGENT_TYPE_LC_LM = 13 # light cyan and light magenta
+AGENT_TYPE_Y_M = 14 # yellow and magenta
+AGENT_TYPE_C_K = 15 # cyan and black
+AGENT_TYPE_LG_PK = 16 # light grey and photo black
+AGENT_TYPE_LG = 17 # light grey
+AGENT_TYPE_G = 18 # medium grey
+AGENT_TYPE_PG = 19 # photo grey
 AGENT_TYPE_WHITE = 0x20 # For ISO 10180 compatibility
 AGENT_TYPE_RED = 0x21 # For ISO 10180 compatibility
 AGENT_TYPE_UNSPECIFIED = 0x3e # (62) Used for kind = 5, 6, 7, 8, or 9
@@ -446,7 +479,8 @@ AGENT_TYPE_ERROR = 0x3f # (63)
 
 # 'health'
 AGENT_HEALTH_OK = 0
-AGENT_HEALTH_MISINSTALLED = 1
+AGENT_HEALTH_MISINSTALLED = 1 # supply/cart
+AGENT_HEALTH_FAIR_MODERATE = 1 # head
 AGENT_HEALTH_INCORRECT = 2
 AGENT_HEALTH_FAILED = 3
 AGENT_HEALTH_OVERTEMP = 4 # Battery
@@ -487,6 +521,7 @@ ALIGN_TYPE_LIDIL_VIP = 7
 ALIGN_TYPE_DESKJET_450 = 8
 ALIGN_TYPE_9XX_NO_EDGE_ALIGN = 9
 ALIGN_TYPE_LBOW = 10
+ALIGN_TYPE_LIDIL_0_5_4 = 11
 
 # clean-types
 CLEAN_TYPE_NONE = 0
@@ -507,7 +542,20 @@ STATUS_TYPE_NONE = 0
 STATUS_TYPE_VSTATUS = 1
 STATUS_TYPE_S = 2
 STATUS_TYPE_LJ = 3
-STATUS_TYPE_S_W_BATTERY = 4
+#STATUS_TYPE_S_W_BATTERY = 4 # DEPRECATED
+#STATUS_TYPE_S_SNMP = 5 # DEPRECATED
+STATUS_TYPE_LJ_XML = 6
+#STATUS_TYPE_S_LIDIL = 7 # DEPRECATED
+
+# status-battery-check-types
+STATUS_BATTERY_CHECK_NONE = 0
+STATUS_BATTERY_CHECK_STD = 1 # Deskjet 450
+
+# status-dynamic-counters-type
+STATUS_DYNAMIC_COUNTERS_NONE = 0
+STATUS_DYNAMIC_COUNTERS_PCL = 1
+STATUS_DYNAMIC_COUNTERS_PML_SNMP = 2
+STATUS_DYNAMIC_COUNTERS_LIDIL_0_5_4 = 3 # Deskjet D4100
 
 # tech-types
 TECH_TYPE_NONE = 0
@@ -516,10 +564,16 @@ TECH_TYPE_COLOR_INK = 2
 TECH_TYPE_MONO_LASER = 3
 TECH_TYPE_COLOR_LASER = 4
 
+# support-type
+SUPPORT_TYPE_NONE = 0
+SUPPORT_TYPE_HPIJS = 1
+SUPPORT_TYPE_HPLIP = 2
+
 # fax-types
 FAX_TYPE_NONE = 0
-FAX_TYPE_BLACK_SEND = 1
-FAX_TYPE_BLACK_AND_COLOR_SEND = 2
+FAX_TYPE_BLACK_SEND_EARLY_OPEN = 1 # newer models
+FAX_TYPE_BLACK_SEND_LATE_OPEN = 2 # older models
+FAX_TYPE_BLACK_AND_COLOR_SEND = 3 # future
 
 # pcard-types
 PCARD_TYPE_NONE = 0
@@ -576,6 +630,7 @@ IO_SUPPORT_WIRELESS = 0x8
 IO_SUPPORT_BLUETOOTH = 0x10
 
 # Model categories
+MODEL_TYPE_UNSUPPORTED = -1
 MODEL_TYPE_COLOR_INKJET = 0
 MODEL_TYPE_PHOTOSMART = 1
 MODEL_TYPE_COLOR_LASER = 2
