@@ -106,7 +106,12 @@ start() {
         echo
         [ $RETVAL = 0 ] && [ -d /var/lock/subsys ] && touch /var/lock/subsys/hpssd.py
 #        killall -HUP cupsd
-        return $RETVAL
+        if [ -f /var/lock/subsys/hpiod -a -f /var/lock/subsys/hpssd.py ]; then
+           touch /var/lock/subsys/hplip
+           return 0
+        else
+           return 1
+	fi
 }
 
 stop() {
@@ -128,6 +133,9 @@ stop() {
                    rm $pidfile
 	   esac
         done
+        if [ ! -f /var/lock/subsys/hpiod -o ! -f /var/lock/subsys/hpssd.py ]; then
+        	rm -f /var/lock/subsys/hplip
+        fi
         return $RETVAL
 }       
 
@@ -136,6 +144,40 @@ restart() {
         start
 }       
 
+debug() {
+        # Allow core dumps.
+        ulimit -c unlimited
+
+        echo -n $"Starting hpiod: "
+        cd $HPIODDIR
+        ./hpiod >/dev/null 2>&1
+        RETVAL=$?
+        if [ $RETVAL -eq 0 ]; then
+           echo -ne "                                           [  OK  ]\r"
+        else
+           echo -ne "                                           [FAILED]\r"
+        fi
+        echo
+        [ $RETVAL = 0 ] && [ -d /var/lock/subsys ] && touch /var/lock/subsys/hpiod
+        echo -n $"Starting hpssd: "
+        cd $HPSSDDIR
+        ./hpssd.py >/dev/null 2>&1
+        RETVAL=$?
+        if [ $RETVAL -eq 0 ]; then
+           echo -ne "                                           [  OK  ]\r"
+        else
+           echo -ne "                                           [FAILED]\r"
+        fi
+        echo
+        [ $RETVAL = 0 ] && [ -d /var/lock/subsys ] && touch /var/lock/subsys/hpssd.py
+        if [ -f /var/lock/subsys/hpiod -a -f /var/lock/subsys/hpssd.py ]; then
+           touch /var/lock/subsys/hplip
+           return 0
+        else
+           return 1
+	fi
+}
+
 case "$1" in
   start)
         start
@@ -153,6 +195,9 @@ case "$1" in
   condrestart)
         [ -f /var/lock/subsys/hpiod ] && [ -f /var/lock/subsys/hpssd.py ] && restart || :
         ;;
+  debug)
+        debug
+        ;;
   *)
         echo $"Usage: $0 {start|stop|status|restart|condrestart}"
         exit 1
